@@ -60,7 +60,6 @@ d_to_p_superiority <- function(d) {
 }
 
 #' @export
-#' @importFrom stats pnorm
 d_to_p_superiority.numeric <- function(d) {
   stats::pnorm(d / sqrt(2))
 }
@@ -89,7 +88,6 @@ d_to_u2 <- function(d) {
 }
 
 #' @export
-#' @importFrom stats pnorm
 d_to_u2.numeric <- function(d) {
   stats::pnorm(abs(d) / 2)
 }
@@ -117,7 +115,6 @@ d_to_u3 <- function(d) {
 }
 
 #' @export
-#' @importFrom stats pnorm
 d_to_u3.numeric <- function(d) {
   stats::pnorm(d)
 }
@@ -132,7 +129,6 @@ d_to_overlap <- function(d) {
 }
 
 #' @export
-#' @importFrom stats pnorm
 d_to_overlap.numeric <- function(d) {
   2 * stats::pnorm(-abs(d) / 2)
 }
@@ -259,11 +255,26 @@ d_to_overlap.effectsize_difference <- function(d) {
 
 ## Main ----------------
 
+#' @keywords internal
+.is_cles_applicable <- function(d, allow_paired = FALSE) {
+  paired <- attr(d, "paired")
+  pooled_sd <- attr(d, "pooled_sd")
+
+  # Effect size is d or g
+  any(colnames(d) %in% c("Cohens_d", "Hedges_g")) &&
+    (
+      # Is paired when allowed
+      (isTRUE(paired) && allow_paired) ||
+        # Is one sample when allowed
+        (!isTRUE(paired) && is.null(pooled_sd) && allow_paired) ||
+        # Is independent with pooled sd
+        (!isTRUE(paired) && isTRUE(pooled_sd))
+    )
+}
+
 #' @keywords internal
 .cohens_d_to_cles <- function(d, converter, allow_paired = FALSE) {
-  if (!any(colnames(d) %in% c("Cohens_d", "Hedges_g")) ||
-    (isTRUE(attr(d, "paired")) && !allow_paired) ||
-    (!isTRUE(attr(d, "paired")) && !isTRUE(attr(d, "pooled_sd")))) {
+  if (!.is_cles_applicable(d, allow_paired)) {
     insight::format_error("Common language effect size only applicable to 2-sample Cohen's d with pooled SD.")
   }
 
